@@ -405,7 +405,7 @@ class column:
                 mat_tmp = y_result[:, ii*N : (ii+1)*N]
                 y_tmp.append(mat_tmp@self._A_flip)
             y_flip = np.concatenate(y_tmp, axis = 1)
-            y_result = y_flip
+            y_result = y_flip 
         self._y = y_result
         self._t = t_dom
         toc = time.time()/60 - tic
@@ -464,21 +464,22 @@ class column:
     def breakthrough(self, draw_graph = False):
         N = self._N
         n_comp = self._n_comp
-        C_end =[]
-        C_ov = np.zeros(len(self._t))
-        for ii in range(n_comp):
-            Cend_tmp = self._y[:,(ii+1)*N-1]
-            C_end.append(Cend_tmp)
+        C_end =[]                                   # initialize an empty array for concentration at z = L
+        C_ov = np.zeros(len(self._t))               # initialize all zero-ed array for concentration throughout all time
+        for ii in range(n_comp):                    # goes through each component, here ii = 0 is CO and ii = 1 is CO2
+            Cend_tmp = self._y[:,(ii+1)*N-1]        # self._y is a 2-dimensional array where [concentration, species]
+            C_end.append(Cend_tmp)                  # check this suspicious operation
             C_ov = C_ov + Cend_tmp
-        y = []
-        fn_y = [] 
+        y = []                                      # initialize an empty array for concentration
+        fn_y = []                                   # initialize an empty array for ???
         for ii in range(n_comp):
-            y_tmp = C_end[ii]/C_ov
+            y_tmp = C_end[ii]/C_ov                  # convert to mole fraction
             y.append(y_tmp)
             fn_tmp = interp1d(self._t, y_tmp, kind = 'cubic' ) 
             fn_y.append(fn_tmp)
         if draw_graph:
-            t_dom = np.linspace(self._t[0], self._t[-1],1001)
+            t_dom = np.linspace(self._t[0], self._t[-1],1001) # get run time for the simulation
+            print(t_dom)
             y_again = []
             plt.figure(figsize = [8,5], dpi = 90)
             for ii in range(n_comp):
